@@ -16,11 +16,11 @@ class ResponseErrorSystemBusyException(ResponseErrorException):
     pass
 
 
-class ResponseErrorLoginCsfrException(ResponseErrorException):
-    """Deprecated misspelling, use ResponseErrorLoginCsrfException instead."""
+class ResponseErrorLoginCsrfException(ResponseErrorException):
+    pass
 
 
-class ResponseErrorLoginCsrfException(ResponseErrorLoginCsfrException):
+class ResponseErrorWrongSessionToken(ResponseErrorException):
     pass
 
 
@@ -46,3 +46,7 @@ class LoginErrorUsernamePasswordOverrunException(ResponseErrorException):
 
 class LoginErrorUsernamePasswordModifyException(ResponseErrorException):
     pass
+
+
+class RequestFormatException(ResponseErrorException):
+    pass
